almohad_design_system library
Classes
- ActionButton
- AnimatedDialogButtonState
- AnimatedInfoButton
- AnimatedToggleSwitch
- AnimatedToggleSwitchState
- ArcPainter
- BaseText
- ChatMessage
- ChatWidget
- Claymorphism
- CustomAvatar
- CustomButton
- CustomButtonState
- CustomChatInput
- CustomDateHelper
- CustomImageIcon
- CustomTextField
- CustomTextFieldState
- CustomToasts
- DesignSystem
- DesignSystem - A centralized class for reusable UI components
- ExpandableWidget
- Glassmorphism
- A glassmorphic effect widget with customizable blur, transparency, and border.
- LinkText
- LiveDateTimeProvider
- return the current time in seconds
- LocationWidgetState
- Neumorphism
- Nil
- A widget which is not in the layout and does nothing. It is useful when you have to return a widget and can't return null.
- SecondaryToggleSwitch
- TimeStatusWidget
- ToastProvider
- ToastProviderState
- TransformingAnimatedToggleSwitch
- TransformingAnimatedToggleSwitchState
Enums
- ActionStatus
- AvatarType
- Enum to define the shape of the avatar
- ButtonAnimationType
- ButtonType
- ButtonVariant
- ChatStatus
- ChatWidgetType
- ContainerStyle
- CustomTextFieldType
- IconAffinity
- ImageViewType
- ToastType
- Enum representing different types of toasts
- TransformType
Constants
- nil → const Nil
- https://github.com/letsar/nil A Nil instance, you can use in your layouts.
Functions
-
customLoader(
BuildContext context, {String? lottie}) → dynamic