AnimatedInfoButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedInfoButton
Constructors
- AnimatedInfoButton({Key? key, String primaryTitle = "Continue", String secondaryTitle = "Cancel", String title = "Title", String description = "Description goes here...", Widget icon = const Icon(Icons.info, size: 40), Color backgroundColor = Colors.white, Color? textColor, Color primaryButtonColor = Colors.white, Color secondaryButtonColor = Colors.red, TextStyle titleStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.bold), TextStyle descriptionStyle = const TextStyle(fontSize: 14, color: Colors.white70), double borderRadius = 15.0, Duration animationDuration = const Duration(milliseconds: 300), Curve animationCurve = Curves.easeInOut, VoidCallback? onPrimaryPressed, VoidCallback? onSecondaryPressed})
-
const
Properties
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- backgroundColor → Color
-
final
- borderRadius → double
-
final
- description → String
-
final
- descriptionStyle → TextStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPrimaryPressed → VoidCallback?
-
final
- onSecondaryPressed → VoidCallback?
-
final
- primaryButtonColor → Color
-
final
- primaryTitle → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryButtonColor → Color
-
final
- secondaryTitle → String
-
final
- textColor → Color?
-
final
- title → String
-
final
- titleStyle → TextStyle
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → AnimatedDialogButtonState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited